@@ -30,12 +30,12 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_INTTYPES_H
-#include <inttypes.h>
-#endif
-
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
 #include <audiofile.h>
 
 #define TEST_FILE "/tmp/test.wave"
